@@ -12,8 +12,9 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14/Bounding_volumes/include/CGAL/Min_ellipse_2.h $
+// $Id: Min_ellipse_2.h 82d4479 %aI Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0+
 // 
 //
 // Author(s)     : Sven Schoenherr <sven@inf.ethz.ch>, Bernd Gaertner
@@ -26,6 +27,7 @@
 
 #include <CGAL/Optimisation/basic.h>
 #include <CGAL/Random.h>
+#include <CGAL/algorithm.h>
 #include <list>
 #include <vector>
 #include <algorithm>
@@ -346,7 +348,7 @@ class Min_ellipse_2 {
     
                     // shuffle points at random
                     std::vector<Point> v( first, last);
-                    std::random_shuffle( v.begin(), v.end(), random);
+                    CGAL::cpp98::random_shuffle( v.begin(), v.end(), random);
                     std::copy( v.begin(), v.end(),
                                std::back_inserter( points)); }
                 else
@@ -358,7 +360,20 @@ class Min_ellipse_2 {
     
     // default constructor
     inline
-    Min_ellipse_2( const Traits& traits = Traits())
+    Min_ellipse_2()
+        : n_support_points( 0)
+    {
+        // allocate support points' array
+        support_points = new Point[ 5];
+    
+        // initialize ellipse
+        tco.ellipse.set();
+    
+        CGAL_optimisation_postcondition( is_empty());
+    }
+
+    inline
+    Min_ellipse_2( const Traits& traits )
         : tco( traits), n_support_points( 0)
     {
         // allocate support points' array
