@@ -12,8 +12,9 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14/QP_solver/include/CGAL/QP_solver/QP_basis_inverse.h $
+// $Id: QP_basis_inverse.h ee57fc2 %aI Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0+
 // 
 //
 // Author(s)     : Sven Schoenherr
@@ -24,6 +25,9 @@
 #ifndef CGAL_QP_SOLVER_QP_BASIS_INVERSE_H
 #define CGAL_QP_SOLVER_QP_BASIS_INVERSE_H
 
+#include <CGAL/license/QP_solver.h>
+
+
 #include <CGAL/QP_solver/basic.h>
 #include <CGAL/IO/Verbose_ostream.h>
 #include <vector>
